@@ -10,6 +10,7 @@ from sqlalchemy.orm import sessionmaker, scoped_session
 
 
 class DAO(object):
+    session = None
 
     def __init__(self):
         host_server = os.environ.get('POSTGRES_HOST', 'postgres')
@@ -23,14 +24,11 @@ class DAO(object):
                                                             db_server_port, database_name)
         print(DATABASE_URL)
         # engine = create_engine('postgresql+psycopg2://streams:REPLACE_ME@postgres:5432/amba')
-        engine = create_engine(DATABASE_URL)
-        Base.metadata.create_all(engine)
+        self.engine = create_engine(DATABASE_URL, pool_size=20, max_overflow=0)
+        Base.metadata.create_all(self.engine)
         # database = databases.Database(DATABASE_URL)
 
         # Session = sessionmaker(bind=engine)
-        session_factory = sessionmaker(bind=engine)
-        Session = scoped_session(session_factory)
-        self.session = Session()
 
     def save_object(self, obj):
         # try:
@@ -40,7 +38,6 @@ class DAO(object):
         #     print('error')
         #     self.session.rollback()
 
-
     def get_object(self, table, key):
         result = self.session.query(table).filter_by(**key).first()
         if not result:
@@ -59,6 +56,10 @@ class DAO(object):
         return self.get_object(Publication, {'doi': doi})
 
     def save_publication(self, publication_data):
+        session_factory = sessionmaker(bind=self.engine)
+        Session = scoped_session(session_factory)
+        self.session = Session()
+
         publication = Publication(doi=publication_data['doi'], type=publication_data['type'],
                                   pubDate=publication_data['pubDate'], year=publication_data['year'],
                                   publisher=publication_data['publisher'],
@@ -67,6 +68,7 @@ class DAO(object):
                                   normalizedTitle=publication_data['normalizedTitle'],
                                   abstract=publication_data['abstract'])
         publication = self.save_if_not_exist(publication, Publication, {'doi': publication.doi})
+
         logging.warning('publication.doi')
         logging.warning(publication.doi)
         logging.warning(publication.id)
@@ -104,6 +106,7 @@ class DAO(object):
                     publication_fos = PublicationFieldOfStudy(**{'fieldOfStudyId': fos.id, 'publicationDoi': publication.doi})
                     self.save_if_not_exist(publication_fos, PublicationFieldOfStudy, {'fieldOfStudyId': fos.id, 'publicationDoi': publication.doi})
 
+        self.session.close()
         return publication
         # todo
         # publicationCitations = PublicationCitations()
